# riot

A Python virtual environment constructor and command runner.

[![Read the Docs](https://img.shields.io/readthedocs/ddriot?style=for-the-badge)](https://ddriot.readthedocs.io/)
[![Pyversions](https://img.shields.io/pypi/pyversions/riot.svg?style=for-the-badge)](https://pypi.org/project/riot/)
[![PypiVersions](https://img.shields.io/pypi/v/riot.svg?style=for-the-badge)](https://pypi.org/project/riot/)
[![Tests](https://img.shields.io/github/workflow/status/DataDog/riot/CI?label=Tests&style=for-the-badge)](https://github.com/DataDog/riot/actions?query=workflow%3ACI)
[![Codecov](https://img.shields.io/codecov/c/github/DataDog/riot?style=for-the-badge)](https://codecov.io/gh/DataDog/riot)


## installation

Install from PyPI:

```sh
pip install riot
```

or install from source:

```sh
pip install git+https://github.com/DataDog/riot.git
```
